@@ -4,8 +4,11 @@ Copyright (c) 2010-2013, Anthony Garcia <anthony@lagg.me>
 Distributed under the ISC License (see LICENSE)
 """
 
-import os, re, json
-from socket import timeout
+import os
+import re
+import json
+import socket
+import sys
 
 # Python 2 <-> 3 glue
 try:
@@ -112,6 +115,7 @@ class http_downloader(object):
     def _build_headers(self):
         head = {}
 
+        # TODO Ask for and handle gzip encoding (add gzip=True param to downloader to control it)
         if self._last_modified:
             head["If-Modified-Since"] = str(self._last_modified)
 
@@ -143,8 +147,10 @@ class http_downloader(object):
                 raise HTTPStale(str(self._last_modified))
             else:
                 raise HTTPError("Server connection failed: {0} ({1})".format(reason, code))
-        except (timeout, urlerror.URLError):
+        except (socket.timeout, urlerror.URLError):
             raise HTTPTimeoutError("Server took too long to respond")
+        except socket.error as E:
+            raise HTTPError("Server read error: {0}".format(E))
 
         lm = req.headers.get("last-modified")
         self._last_modified = lm
@@ -175,7 +181,15 @@ class method_result(dict):
 
     def _call_method(self):
         """ Download the URL using last-modified timestamp if given """
-        self.update(json.loads(self._downloader.download().decode("utf-8")))
+        data = self._downloader.download()
+
+        # Only try to pass errors arg if supported
+        if sys.version >= "2.7":
+            data = data.decode("utf-8", errors="ignore")
+        else:
+            data = data.decode("utf-8")
+
+        self.update(json.loads(data))
         self._fetched = True
 
     def get(self, key, default = None):
